import React, { useState, useEffect, useCallback } from 'react';
import { string, shape } from 'prop-types';

import { useStyle } from '@magento/venia-ui/lib/classify';
import defaultClasses from './carousel.module.css';

import ItemList from './itemList';
// import Button from '@magento/venia-ui/lib/components/Button/button';

const TYPE_ALL = 'Swissup\\Highlight\\Block\\ProductList\\All';
const TYPE_POPULAR = 'Swissup\\Highlight\\Block\\ProductList\\Popular';
const TYPE_BESTSELLERS = 'Swissup\\Highlight\\Block\\ProductList\\Bestsellers';
const TYPE_ONSALE = 'Swissup\\Highlight\\Block\\ProductList\\Onsale';

const Carousel = props => {

    const classes = useStyle(defaultClasses, props.classes);

    const { blockData : {
        type,
        carousel,
        category_ids,
        column_count,
        dir: defaultDir = "ASC",
        mode,
        order: defaultOrder = "default",
        page_count,
        products_count,
        period = "P1M"
    } } = props;

    const [isCarousel, setIsCarousel] = useState(
        // carousel === 1 || carousel === "1"
        true
    );

    const getCollectionType = (type) => {
        let collectionType = "default";

        switch (type) {
            case TYPE_POPULAR:
                collectionType = "popular";
                break;

            case TYPE_BESTSELLERS:
                collectionType = "bestsellers";
                break;

            case TYPE_ONSALE:
                collectionType = "onsale";
                break;

            case TYPE_ALL:
            default:
                collectionType = "default";
        }

        return collectionType;
    };

    const [collectionType, setCollectionType] = useState(getCollectionType(type));
    const [currentPage, setCurrentPage] = useState(1/*page_count*/);
    const [pageSize, setPageSize] = useState(parseInt(products_count));
    const [order, setOrder] = useState(
        defaultOrder === "default" ?
            (type === TYPE_POPULAR ? "popularity" : "position") : defaultOrder
    );
    const [dir, setDir] = useState(defaultDir.toUpperCase());

    useEffect(() => {
        setCollectionType(getCollectionType(type));
    }, [type, setCollectionType, getCollectionType]);

    const incCurrentPage = useCallback(() => {
        setCurrentPage(prevCurrentPage => prevCurrentPage + 1);
    }, [currentPage, setCurrentPage]);

    const decCurrentPage = useCallback(() => {
        setCurrentPage(
            prevCurrentPage =>
                (prevCurrentPage > 1 ? prevCurrentPage - 1 : prevCurrentPage)
        );
    }, [currentPage, setCurrentPage]);

    const [totalPages, setTotalPages] = useState(1);

    const isPrevDisabled = currentPage === 1;
    const isNextDisabled = currentPage === totalPages;

    const itemListProps = {
        collectionType,
        currentPage,
        pageSize,
        order,
        dir,
        period,
        setTotalPages
    };

    const prevClasses = `${classes.prev} ${(isPrevDisabled ? classes.disabled : '')}`;
    const nextClasses = `${classes.next} ${(isNextDisabled ? classes.disabled : '')}`;

    const controls = totalPages > 1 ? (<>
        <div className={prevClasses} onClick={decCurrentPage} disabled={isPrevDisabled}/>
        {/*<div>{currentPage} of {totalPages}</div>*/}
        <div className={nextClasses} onClick={incCurrentPage} disabled={isNextDisabled}/>
    </>) : '';

    return (
        <div className={classes.root}>
            {isCarousel ? (<div className={classes.gallery}>
                <ItemList {...itemListProps} />
                {controls}
                {/*<div>
                    {"Carousel"}
                    <p>carousel: {carousel}</p>
                    <p>category_ids : {category_ids}</p>
                    <p>column_count : {column_count}</p>
                    <p>dir: {dir}</p>
                    <p>mode : {mode}</p>
                    <p>order : {order}</p>
                    <p>page_count : {page_count}</p>
                    <p>products_count : {products_count}</p>
                </div>*/}
            </div>) : ''}
        </div>
    )
};

Carousel.propTypes = {
    classes: shape({
        gallery: string,
        root: string
    }),
    blockData: shape({
        type: string,
        carousel: string,
        category_ids: string,
        column_count: string,
        dir: string,
        mode: string,
        order: string,
        page_count: string,
        products_count: string
    })
};

export default Carousel;