import React, { useEffect, useMemo } from 'react';
import { string, number, shape, array } from 'prop-types';

import { useStyle } from '@magento/venia-ui/lib/classify';
import defaultClasses from './itemList.module.css';
import { useHighlightContent } from '@swissup/pwa-highlight/lib/talons/HighlightContent/useHighlightContent';
import { useGallery } from '@magento/peregrine/lib/talons/Gallery/useGallery';
import highlightOperations from '@swissup/pwa-highlight/lib/queries/getHighlightProducts.gql';

// import Gallery from '@magento/venia-ui/lib/components/Gallery';
import GalleryItem from '@magento/venia-ui/lib/components/Gallery/item';

// map Magento 2.3.1 schema changes to Venia 2.0.0 proptype shape to maintain backwards compatibility
const mapGalleryItem = item => {
    return item;
    // const { small_image } = item;
    // return {
    //     ...item,
    //     small_image:
    //         typeof small_image === 'object' ? small_image.url : small_image
    // };
};


const ItemList = props => {

    const classes = useStyle(defaultClasses, props.classes);

    const {
        collectionType = "default",
        currentPage = 1,
        pageSize = 8,
        order = "position",
        dir = "ASC",
        period = "P1M",
        setTotalPages
    } = props;

    const talonProps = useHighlightContent({
        collectionType,
        currentPage,
        pageSize,
        order,
        dir,
        period,
        ...highlightOperations
    });

    const {
        products,
        isLoading,
        page_info: {
            total_pages: totalPages
        },
        total_count: totalCount
    } = talonProps;

    const { storeConfig } = useGallery();

    // useEffect(() => {
    //     console.log('-= is loading =-');
    //     console.log(isLoading);
    //     return () => {};
    // }, [isLoading]);

    useEffect(() => {
        setTotalPages(totalPages);
    }, [totalPages, setTotalPages]);

    const pendingItems = useMemo(
        () => Array.from({ length: pageSize }).fill(null).map((item, index) => {
                return <GalleryItem key={index} />;
            })
        ,
        [pageSize]
    );

    const galleryItems = useMemo(
        () =>
            products.map(item => {
                if (item === null) {
                    return <GalleryItem key={item.id} />;
                }
                return (
                    <GalleryItem
                        key={item.id}
                        item={mapGalleryItem(item)}
                        storeConfig={storeConfig}
                    />
                );
            }),
        [products, storeConfig]
    );

    const itemsClasses = `${classes.items} ${pageSize % 4 ?
        `${classes.columns3}` : `${classes.columns4}`}`;

    return (
        <div className={classes.root}>
            <div className={itemsClasses}>
                {isLoading ? (<>{pendingItems}</>) : (<>{galleryItems}</>)}
            </div>
        </div>
    )
};

ItemList.propTypes = {
    classes: shape({
        filters: string,
        items: string,
        columns3: string,
        columns4: string,
        pagination: string,
        root: string
    }),
    collectionType: string.isRequired,
    currentPage: number.isRequired,
    pageSize: number.isRequired,
    order: string.isRequired,
    dir: string.isRequired,
};

export default ItemList;