import { getCssClasses } from '@magento/pagebuilder/lib/utils';

const getAttribute = (element, attribute, defaultValue = '') => {
    return element && element.getAttribute(attribute) ? element.getAttribute(attribute) : defaultValue;
};

const unescapeHtml = (html) => {
    const tempElement = document.createElement("div");
    tempElement.innerHTML = html;
    return tempElement.textContent || tempElement.innerText || "";
};

export default (node, props) => {

    const isPagebuilder = node
        && node.hasAttribute('data-appearance')
        && node.hasAttribute('data-element')
        && node.hasChildNodes();

    const dataNode = isPagebuilder ? node.childNodes[0] : node;

    const titleStrongElement = dataNode.querySelector('div.block-title strong');
    if (titleStrongElement) {
        titleStrongElement.innerHTML = unescapeHtml(titleStrongElement.innerHTML);
    }

    const titleElement = dataNode.querySelector('div.block-title');
    const titleHtml = titleElement && titleElement.innerHTML ?
        titleElement.innerHTML : '';

    const imgElement = dataNode.querySelector('div.block-title span.title-image img');

    let configCarousel = {};
    let enabled = false;

    const configElement = dataNode.querySelector('div.block-content div.swiper-config');
    if (configElement && configElement.hasAttribute('data-config')) {
        let dataConfig = configElement.getAttribute('data-config');
        try {
            dataConfig = JSON.parse(dataConfig);
        } catch (e) {
            dataConfig = {};
        }
        enabled = true;
        configCarousel = dataConfig;
    } else {
        const containerElement = dataNode.querySelector('div.block-content div.swiper-container');
        if (containerElement && containerElement.hasAttribute('data-mage-init')) {
            let mageDataInit = containerElement.getAttribute('data-mage-init');
            try {
                mageDataInit = JSON.parse(mageDataInit);
            } catch (e) {

            }

            if (mageDataInit.hasOwnProperty('Swissup_Highlight/js/carousel')) {
                enabled = true;
                configCarousel = mageDataInit['Swissup_Highlight/js/carousel'];
            }
        }
    }

    return {
        enabled,
        nodeClasses: getCssClasses(dataNode).cssClasses,
        title: {
            html: titleHtml,
            img: {
                src: getAttribute(imgElement, 'src', false),
                width: getAttribute(imgElement, 'width', 276),
                height: getAttribute(imgElement, 'height', 440)
            }
        },
        carousel: configCarousel
    };
}